
/* WiFi Internetové rádio ESP 32 s VS 1053B Shield ( nebo kompatibilní )
 David Kohout 18.BŘEZNA 2020

 * WiFi připojení
 * Ovládání pouze 2 tlačítky
 * Aktualizace SW v ESP 32 pomocí WiFi
 * Předvoleno 200 rozhlasových stanic

Zapojení hardware :

---------------------------------------------
|   VS1053 |  ESP 8266 | ESP 32 | PŘIŘAZENÍ |
---------------------------------------------
|   13 SCK        D5     GPIO 18    SCK     |
|                                           |
|   12 MISO       D6     GPIO 19    MISO    |
|                                           |
|   11 MOSI       D7     GPIO 23    MOSI    |
|                                           |
|    8 XRST       RST      EN       RESET   |
|                                           |
|    9 XCS        D1      GPIO05     XCS    |
|                                           |
|    7 DCS        D0      GPIO16     DCS    |
|                                           |
|    2 DREQ       D3      GPIO04     DREQ   |
|                                           |
|                         GPIO13    Tlač.+  |
|                                           |
|                         GPIO12    Tlač.-  |
|                                           |
|                         GPIO21    I2C SDA |
|                                           |
|                         GPIO22    I2C SCL |
|                                           |
|     5 V         5V        5 V     Napájení|
|                                           |
|     GND         GND       GND     Napájení|
|                                           |
|        TLAČÍTKA SPÍNAJÍ GND !!!           |
|                                           |
---------------------------------------------



*/
// Obsahuje standartní knihovny
#include <WiFi.h>                   // WiFi podpora
#include <ESPmDNS.h>                // OTA - On The Air - bezdrátový přenos souborů
#include <WiFiUdp.h>                // OTA - On The Air - bezdrátový přenos souborů
#include <ArduinoOTA.h>             // OTA - On The Air - bezdrátový přenos souborů
#include <HTTPClient.h>             // Klient - nějaké data z Internetu
#include <esp_wifi.h>               // ESP32 specifické WiFi funkce
#include <LiquidCrystal_I2C.h>      // Displej I2C
#include <Bounce2.h>                // Vyhodnocení stavu tlačítek - autor Thomas Ouellet Fredericks

// Nyní přidejte knihovny pro práci s hardwarem, který používáme
// VS1053 stáhneme na https://github.com/baldram/ESP_VS1053_Library
// Stáhnout a nainstalovat knihovnu ze ZIP souboru

#include <VS1053.h>                 // VS0153 základní MP3 dekodér

// Používáme standardní SPI piny, ale budeme muset definovat
// extra piny pro CS, DCS, a DREQ.

#define VS1053_CS    5  // GPIO 5 na zvukovce VS1053B Shield pin XCS !
#define VS1053_DCS   16 // GPIO 16
#define VS1053_DREQ  4  // GPIO 4
#define B_PREV 12       // Tlačítko předchozí stanice připojeno mezi GND a pin GPIO 12
#define B_NEXT 13       // Tlačítko další stanice připojeno mezi GND a pin GPIO 13
#define B_PLUS_10 27    // Tlačítko předvolba + 10 připojeno mezi GND a pin GPIO 27
#define B_MINUS_10 26   // Tlačítko předvolba - 10 připojeno mezi GND a pin GPIO 26
#define B_VOL_MINUS 25  // Tlačítko hlasitost - připojeno mezi GND a pin GPIO 25
#define B_VOL_PLUS 33   // Tlačítko hlasitost + připojeno mezi GND a pin GPIO 33
#define BUTTON_DEBOUNCE_PERIOD 20 // Perioda snímání stavu tlačítek v milisekundách

Bounce b_Next  = Bounce();     // Makro tlačítko NEXT ( další stanice + 1 )
Bounce b_Prev  = Bounce();     // Makro tlačítko PREV ( předchozí stanice - 1)
Bounce b_Plus_10 = Bounce();   // Makro tlačítko PLUS_10 ( další stanice + 10 )
Bounce b_Minus_10 = Bounce();  // Makro tlačítko MINUS_10 ( předchozí stanice - 10 )
Bounce b_Vol_minus = Bounce(); // Makro tlačítko VOL_MINUS ( Hlasitost - 1 )
Bounce b_Vol_plus = Bounce();  // Makro tlačítko VOL_PLUS ( Hlasitost + 1 )



LiquidCrystal_I2C lcd(0x27, 16, 2); // LCD na adrese 0x27, 16 znaků, 2 řádky
VS1053 MP3player(5,16,4);  // X_CS 6 pin, X_DCS 7 pin, DREQ 2 pin, X_RESET 8 pin

// Zde zadat přístupové údaje k WiFi

char ssid[] = "XXXXXXXXXXXXX";   // ZDE ZADAT JMÉNO VAŠÍ WIFI SÍTĚ
char pass[] = "YYYYYYYYYYYYY";   // ZDE ZADAT HESLO VAŠÍ WIFI SÍTĚ



uint8_t mp3buff[32];       // Velikost bufferu 32 Byte
const char *host;          // Zde se uloží adresa serveru s požadovaným streamem
const char *path;          // Zde se uloží cesta serveru s požadovaným streamem
int httpPort;              // Zde se uloží port serveru s požadovaným streamem
int ID_stanice=27;         // Zde se uloží číslo aktuálně přehrávané stanice - konstanta číslo stanice, které začne hrát po spuštění Arduina ( 27=Star*Sat Radio)
int pamet_ID_stanice;      // Zde se uloží číslo posledně přehrávané stanice
String nazev="";           // Zde se uloží jméno aktuálně přehrávané stanice
String zanr="";            // Zde se uloží žánr aktuálně přehrávané stanice
int Li          = 16;      // 1 řádek LCD má 16 znaků
int Lii         = 0;       // Pozice počátečního znaku
int Delka_textu = 0;       // Výchozí délka textu
int Prodleva=0;            // Výchozí prodleva
int Volume = 85;           // Výhozí hlasitost při zapnutí

// Definuj instanci VS1053
VS1053 audioplayer(VS1053_CS, VS1053_DCS, VS1053_DREQ);

// Definuj instanci WiFi klienta
WiFiClient webclient;



// Setup code
void setup ()
{
 
pinMode(B_PREV,INPUT_PULLUP);      // Definování tlačítka předchozí stanice - 1
pinMode(B_NEXT,INPUT_PULLUP);      // Definování tlačítka následující stanice + 1
pinMode(B_PLUS_10,INPUT_PULLUP);   // Definování tlačítka následující stanice + 10
pinMode(B_MINUS_10,INPUT_PULLUP);  // Definování tlačítka předchozí stanice - 10
pinMode(B_VOL_MINUS,INPUT_PULLUP); // Definování tlačítka hlasitost - 1
pinMode(B_VOL_PLUS,INPUT_PULLUP);  // Definování tlačítka hlasitost + 1

 b_Next.attach(B_NEXT);     // Aktivace makra pro tlačítko další stanice + 1
 b_Next.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 b_Prev.attach(B_PREV);     // Aktivace makra pro tlačítko předchozí stanice - 1
 b_Prev.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 b_Plus_10.attach(B_PLUS_10);     // Aktivace makra pro tlačítko další stanice + 1
 b_Plus_10.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 b_Minus_10.attach(B_MINUS_10);     // Aktivace makra pro tlačítko předchozí stanice - 10
 b_Minus_10.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 b_Vol_minus.attach(B_VOL_MINUS);     // Aktivace makra pro tlačítko hlasitost - 1
 b_Vol_minus.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 b_Vol_plus.attach(B_VOL_PLUS);     // Aktivace makra pro tlačítko hlasitost + 1
 b_Vol_plus.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 Serial.begin(115200);
 SPI.begin();              // Start SPI sběrnice - u UNO nemusí být
 MP3player.begin();        // Start zvukové karty VS1053B Shield
 
 lcd.init();               // Inicializuj LCD displej
 lcd.backlight();          // Rozsviť displej
 
 Serial.println("Startuji");  // Vypiš na COM informaci o připojování ESP 32
 WiFi.mode(WIFI_STA);         // Mód WiFi
 WiFi.begin(ssid, pass);      // Jméno a heslo Access Point ( Vašeho routeru... )
 while (WiFi.waitForConnectResult() != WL_CONNECTED) {  // Pokud není spojení navázáno, tak...
 Serial.println("Chyba spojení ! Restartuji...");       // Pošli na COM hlášení o chybě
 delay(5000);                                           // a počkej 5 vteřin
 ESP.restart();                                         // a potom restaruj ESP 32
  }

  // -------  Volitelná konfigurace spojení -------------   

  // Port defaults to 3232
  // ArduinoOTA.setPort(3232);

  // Hostname defaults to esp3232-[MAC]
  // ArduinoOTA.setHostname("myesp32");

  // No authentication by default
  // ArduinoOTA.setPassword("admin");

  // Password can be set with it's md5 value as well
  // MD5(admin) = 21232f297a57a5a743894a0e4a801fc3
  // ArduinoOTA.setPasswordHash("21232f297a57a5a743894a0e4a801fc3");

  // -------------------------------------------------------

  ArduinoOTA
    .onStart([]() {
      String type;
      if (ArduinoOTA.getCommand() == U_FLASH)
        type = "sketch";
      else // U_SPIFFS
        type = "filesystem";

      // NOTE: if updating SPIFFS this would be the place to unmount SPIFFS using SPIFFS.end()
      Serial.println("Start updating " + type);
    })
    .onEnd([]() {
      Serial.println("\nEnd");
    })
    .onProgress([](unsigned int progress, unsigned int total) {
      Serial.printf("Progress: %u%%\r", (progress / (total / 100)));
    })
    .onError([](ota_error_t error) {
      Serial.printf("Error[%u]: ", error);
      if (error == OTA_AUTH_ERROR) Serial.println("Auth Failed");
      else if (error == OTA_BEGIN_ERROR) Serial.println("Begin Failed");
      else if (error == OTA_CONNECT_ERROR) Serial.println("Connect Failed");
      else if (error == OTA_RECEIVE_ERROR) Serial.println("Receive Failed");
      else if (error == OTA_END_ERROR) Serial.println("End Failed");
    });

  ArduinoOTA.begin();

  Serial.println("Připraven");
  Serial.print("IP addresa: ");
  Serial.println(WiFi.localIP());
 
   char serinfo[64];
   
   // Nastavení sériového portu pro ladění
   Serial.begin(115200);
//   Serial.print(appname);
   Serial.println(" Startuji...");
   sprintf(serinfo, "Bezim na CPU %d at %dMHz, s %d volne pameti.",
           xPortGetCoreID(), ESP.getCpuFreqMHz(), ESP.getFreeHeap());
   Serial.println(serinfo);
   
 
  // wifi_connect();

   webclient.print(String("GET ") + path + " HTTP/1.1\r\n" +                    // Adresa serveru se streamem - požadavek při spuštění Arduina
                  "Host: " + host + "\r\n" + 
                  "Connection: close\r\n\r\n");

   // Hotovo, dále budeme pracovat ve smyčce...
}


void loop()
{
  ArduinoOTA.handle();        // OTA ESP 32
  
  Prodleva=Prodleva+1;


  if (b_Next.update()) {
    if (b_Next.read() == LOW && ID_stanice <150) {     // Detekována sestupná hrana tlačítka NEXT a není-li rádio aktuálně na poslední stanici, tak :
            ID_stanice=ID_stanice +1;                  // Připočti číslo 1 k číslu aktuálně přehrávané stanice     
    }
  }

  if (b_Prev.update()) {
    if (b_Prev.read() == LOW&& ID_stanice >1) {  // Detekována sestupná hrana tlačítka PREV a není-li rádio aktuálně na první stanici, tak :     
      ID_stanice=ID_stanice -1;                  // Odečti číslo 1 od čísla aktuálně přehrávané stanice
      
     
    }
  }

   if (b_Plus_10.update()) {
    if (b_Plus_10.read() == LOW && ID_stanice <140) {   // Detekována sestupná hrana tlačítka NEXT a není-li rádio aktuálně na poslední stanici, tak :
            ID_stanice=ID_stanice +10;                  // Připočti číslo 10 k číslu aktuálně přehrávané stanice     
    }
  }

    if (b_Minus_10.update()) {
    if (b_Minus_10.read() == LOW&& ID_stanice >11) {  // Detekována sestupná hrana tlačítka PREV a není-li rádio aktuálně na první stanici, tak :    
      ID_stanice=ID_stanice -10;                      // Odečti číslo 10 od čísla aktuálně přehrávané stanice
      
     
    }
  }

    if (b_Vol_plus.update()) {
    if (b_Vol_plus.read() == LOW && Volume <100) {  // Detekována sestupná hrana tlačítka VOLUME PLUS a není-li rádio na max.hlasitost, tak :
            Volume=Volume +5;                      // Připočti číslo 1 k aktuální hlasitosti     
    }
  }

    if (b_Vol_minus.update()) {
    if (b_Vol_minus.read() == LOW && Volume >5) {  // Detekována sestupná hrana tlačítka VOLUME MINUS a není-li rádio na min. hlasitost, tak :
            Volume=Volume -5;                      // Odečti číslo 1 od aktuální hlasitosti        
    }
  }

 switch(ID_stanice){              // Přepínání stanic - ID stanice
        case 1:
             nazev = "Hitradio Osmdesatka";       
             host = "ice.abradio.cz";         // Hitrádio 80
             path = "/hit80128.mp3";
             httpPort = 80;
             zanr="  DISKOTEKA 80 LET";
            break;
        case 2:
           nazev = "Hitradio Devadesatka"; 
           host= "ice.abradio.cz";           // Hitrádio 90
           path = "/hit90128.mp3";
           httpPort = 80;
           zanr="  DISKOTEKA 90 LET";
            break;
        case 3:
            nazev = "Radio Rubi"; 
            host = "icecast8.play.cz";       // Radio Rubi
            path = "/radiorubi128.mp3";
            zanr="       TOP 40";
            httpPort = 80;;
            break;
        case 4:
            nazev = "Dance radio"; 
            host = "icecast6.play.cz";       // Dance Radio
            path = "/dance-radio128.mp3";
            zanr="        DANCE";
            httpPort = 80;;
            break;
        case 5:
            nazev = "FUN radio SK";
            host = "stream.funradio.sk";     // Fun rádio SK
            path = "/dance128.mp3";
            zanr="       TOP 40";
            httpPort = 8000;
            break;
        case 6:
            nazev = "Classic 21 90 BE";
            host = "radios.rtbf.be";     // Classic 21 90´ BE
            path = "/wr-c21-90-128.mp3";
            zanr="  DISKOTEKA 90 LET";
            httpPort = 80;
            break;
        case 7:
            nazev = "Hit West 80";
            host = "streamingp.shoutcast.com";  // Hity 80 let
            path = "/HITWEST80.mp3";
            zanr="  DISKOTEKA 80 LET";
            httpPort = 80;
            break;
        case 8:
            nazev = "105 Hits Italy" ;     // 105 Hits Italy
            host = "icy.unitedradio.it";
            path = "/105Hits.mp3?";
            zanr="       TOP 40";
            httpPort = 80;
            break;
        case 9:
            nazev = "Hitradio Orion Morava"; // CZ Hitrádio Orion Morava
            host = "ice.abradio.cz";
            path = "/orionmorava128.mp3";
            zanr="       TOP 40";
            httpPort = 8000;
            break;
        case 10:
            nazev = "Blanik FM";             // CZ Rádio Blaník FM
            host = "ice.abradio.cz";
            path = "/blanikfm128.mp3";
            zanr="   ZABAVA , ZPRAVY";
            httpPort = 80;
            break;
        case 11:
            nazev = "CRo 1 Radiozurnal";      // CZ CRo 1 Radiožurnál
            host = "icecast7.play.cz";
            path = "/cro1-128.mp3";
            zanr="   ZABAVA , ZPRAVY";
            httpPort =8000;
            break;

         case 12:
            nazev = "CRo 2 Dvojka";      // CZ CRo 2 Dvojka
            host = "icecast7.play.cz";
            path = "/cro2-128.mp3";
            zanr="   ZABAVA , ZPRAVY";
            httpPort =8000;
            break;

         case 13:
            nazev = "Radio Cas Rock";      // CZ Rádio Čas Rock
            host = "icecast7.play.cz";
            path = "/casrock128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 14:
            nazev = "Evropa 2";      // CZ Evropa 2
            host = "icecast3.play.cz";
            path = "/evropa2-128.mp3?";
            zanr="   ZABAVA , ZPRAVY";
            httpPort =80;
            break;

         case 15:
            nazev = "Evropa 2 Top 40";      // CZ Evropa 2 Top 40
            host = "ice.actve.net";
            path = "/web-e2-top40";
            zanr="       TOP 40";
            httpPort =80;
            break;  

         case 16:
            nazev = "KISS 98 FM";      // CZ Kiss 98 FM
            host = "icecast4.play.cz";
            path = "/kiss128.mp3";
            zanr="   ZABAVA , ZPRAVY";
            httpPort =80;
            break; 

         case 17:
            nazev = "Radio Zlin Best Ballads";      // CZ Rádio Zlín Best Ballads
            host = "212.111.2.151";
            path = "/radiozlin_128.mp3";
            zanr="  POHODOVY POSLECH";
            httpPort =8000;
            break;

         case 18:
            nazev = "Rock radio Metalomanie";      // CZ Rock rádio Metalománie
            host = "ice.abradio.cz";
            path = "/metalomanie128.mp3";
            zanr="       METAL";
            httpPort =80;
            break;

         case 19:
            nazev = "Rock Max";      // CZ Rock Max
            host = "212.111.2.151";
            path = "/rockmax_128.mp3";
            zanr="       ROCK";
            httpPort =8000;
            break;

         case 20:
            nazev = "Rock Max Hard";      // CZ Rock Max Hard
            host = "212.111.2.151";
            path = "/rm_hard_128.mp3";
            zanr="       ROCK";
            httpPort =8000;
            break;

         case 21:
            nazev = "Rock Radio - Rockova zabava";      // CZ Rock Radio - Rockova zabava
            host = "ice.abradio.cz";
            path = "/rockzabava128.mp3";
            zanr="       ROCK";
            httpPort =80;
            break;

         case 22:
            nazev = "Radio Bonton - Filmove melodie";      // CZ Radio Bonton - Filmove melodie
            host = "icecast7.play.cz";
            path = "/bonton-128.mp3";
            zanr="  POHODOVY POSLECH";
            httpPort =80;
            break;

        case 23:
            nazev = "Antenne Bayern - 80er Hits";      // Antenne Bayern - 90er Hits
            host = "mp3channels.webradio.antenne.de";
            path = "/80er-kulthits";
            zanr="  DISKOTEKA 80 LET";
            httpPort =80;
            break;

         case 24:
            nazev = "AB Radio Povidka";      // CZ AB Radio Povídka
            host = "ice.abradio.cz";
            path = "/povidka128.mp3";
            zanr="    MLUVENE SLOVO";
            httpPort =80;
            break;

         case 25:
            nazev = "CRo Plus";      // CZ ČRo Plus
            host = "icecast1.play.cz";
            path = "/croplus128.mp3";
            zanr="    MLUVENE SLOVO";
            httpPort =80;
            break;

         case 26:
            nazev = "Frekvence 1 Diskoteka";      // CZ Frekvence 1 Diskoteka
            host = "icecast4.play.cz";
            path = "/frekvence1-128.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 27:
            nazev = "Star*Sat Radio";      // DE STAR*SAT RADIO
            host = "starsat-ais-edge-3005.fra-eco.cdn.addradio.net";
            path = "/starsat/live/mp3/low/stream.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 28:
            nazev = "N-Joy Radio DE";      // DE N-Joy Radio
            host = "ndr-edge-1044-fra-dtag-cdn.sslcast.addradio.de";
            path = "/ndr/njoy/live/mp3/128/stream.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 29:
            nazev = "N-Joy Radio Bulgaria";      // BG N-Joy Radio
            host = "live.btvradio.bg";
            path = "/njoy.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 30:
            nazev = "Alpha Radio Bulgaria";      // BG Alpha Radio
            host = "alpharadio.bg";
            path = "/stream";
            zanr="        POP";
            httpPort =8000;
            break;

         case 31:
            nazev = "All Zic - Zouk";              // FR All Zic - Zouk
            host = "allzic28.ice.infomaniak.ch";
            path = "/allzic28.mp3";
            zanr="      TROPICAL";
            httpPort =80;
            break;

         case 32:
            nazev = "Kultural Online - Antila";    // Kultural Online - Nizozemské Antily
            host = "38.96.148.37";
            path = "/;stream.mp3";
            zanr="      TROPICAL";
            httpPort =9176;
            break;

         case 33:
            nazev = "Red Hot Flames - Antigua and Barbuda ";    // Karibik
            host = "162.244.80.34";
            path = "/;stream.mp3";
            zanr="      TROPICAL";
            httpPort =6444;
            break;

         case 34:
            nazev = "Radio Monte Carlo 80";    // Monako Radio Monaco 80
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb008";
            zanr="  DISKOTEKA 80 LET";
            httpPort =80;
            break;

       case 35:
            nazev = "Radio Monte Carlo 98.2";    // Monako RMC 98.2
            host = "radiomonaco.ice.infomaniak.ch";
            path = "/radiomonaco-128.mp3";
            zanr="        DANCE";
            httpPort =80;
            break;

         case 36:
            nazev = "Radio Monte Carlo Hits";    // Monako RMC Hits
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb001";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 37:
            nazev = "Radio Monte Carlo Kay Kay";    // Monako RMC Kay Kay
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb004";
            zanr="         POP";
            httpPort =80;
            break;

         case 38:
            nazev = "Radio Monte Carlo Marine";    // Monako RMC Marine
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb015";
            zanr="         POP";
            httpPort =80;
            break;

         case 39:
            nazev = "Radio Monte Carlo Italia";    // Monako RMC Italia
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb005";
            zanr="         POP";
            httpPort =80;
            break;

         case 40:
            nazev = "Radio Monte Carlo Great Artist";    // Monako RMC Great Artist
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb007";
            zanr="         POP";
            httpPort =80;
            break;

         case 41:
            nazev = "Music 100.9 Monaco";    // Monako 100.9
            host = "ice12.fluidstream.net";
            path = "/fluid1203.mp3";
            zanr="         POP";
            httpPort =80;
            break;

         case 42:
            nazev = "Cannes Radio France";    // FR Cannes Radio
            host = "cannesradio.ice.infomaniak.ch";
            path = "/cannesradio-128.mp3";
            zanr="         POP";
            httpPort =80;
            break;

         case 43:
            nazev = "Cerise 88.2 FM France";    // FR Cerise 88.2 FM
            host = "cerisefm.ice.infomaniak.ch";
            path = "/cerisefm-128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 44:
            nazev = "Cherie Ballads FR";    // FR Chérie Ballads
            host = "185.52.127.131";
            path = "/fr/30297/mp3_128.mp3";
            zanr="    BEST BALLADS";
            httpPort =80;
            break;

         case 45:
            nazev = "Cherie Celine Dion FR";    // FR Chérie Celine Dion
            host = "185.52.127.168";
            path = "/fr/55507/mp3_128.mp3";
            zanr="         POP";
            httpPort =80;
            break;

         case 46:
            nazev = "Cherie FM FR";    // FR Chérie FM
            host = "185.52.127.163";
            path = "/fr/30201/mp3_128.mp3";
            zanr="         POP";
            httpPort =80;
            break;

          case 47:
            nazev = "Cherie Frenchy";    // FR Chérie Frenchy
            host = "185.52.127.131";
            path = "/fr/30213/mp3_128.mp3?";
            zanr="         POP";
            httpPort =80;
            break;

         case 48:
            nazev = "Cherie Jazzy";    // FR Chérie Jazzy
            host = "185.52.127.159";
            path = "/fr/30241/mp3_128.mp3?";
            zanr="        JAZZ";
            httpPort =80;
            break;

         case 49:
            nazev = "Cherie Latino";    // FR Chérie Latino
            host = "185.52.127.159";
            path = "/fr/30247/mp3_128.mp3?";
            zanr="       LATINO";
            httpPort =80;
            break;

         case 50:
            nazev = "Cherie Les plus belles voix";    // FR Chérie Les plus belles voix
            host = "185.52.127.131";
            path = "/fr/30317/mp3_128.mp3?";
            zanr="        LOVE";
            httpPort =80;
            break;

         case 51:
            nazev = "Cherie No Repeat";    // FR Chérie No Repeat
            host = "185.52.127.159";
            path = "/fr/30295/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 52:
            nazev = "Cherie 80s";    // FR Chérie 80s
            host = "185.52.127.159";
            path = "/fr/30237/mp3_128.mp3?";
            zanr="  DISKOTEKA 80 LET";
            httpPort =80;
            break;

         case 53:
            nazev = "Cherie @ Work";    // FR Chérie @ Work
            host = "185.52.127.131";
            path = "/fr/30215/mp3_128.mp3?";
            zanr="         POP";
            httpPort =80;
            break;

         case 54:
            nazev = "Cherie Acoustic";    // FR Chérie Acoustic
            host = "185.52.127.159";
            path = "/fr/30269/mp3_128.mp3?";
            zanr="       OLDIES";
            httpPort =80;
            break;

         case 55:
            nazev = "Cherie Adele";    // FR Chérie Adele
            host = "185.52.127.132";
            path = "/fr/30201/mp3_128.mp3?origine=mytuner";
            zanr="         POP";
            httpPort =80;
            break;

         case 56:
            nazev = "Cherie Pop Love";    // FR Chérie Pop Love
            host = "185.52.127.162";
            path = "/fr/30207/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 57:
            nazev = "Cherie Romantic";    // FR Chérie Romantic
            host = "185.52.127.172";
            path = "/fr/30287/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 58:
            nazev = "Cherie Sweet Home";    // FR Chérie Sweet Home
            host = "185.52.127.172";
            path = "/fr/30289/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 59:
            nazev = "Aktina 104,7 FM Corfu";    // GR Aktina 104,7 FM Corfu
            host = "live.e-streaming.eu";
            path = "/";
            zanr="       TOP 40";
            httpPort =8110;
            break;

         case 60:
            nazev = "Arion Eurovision GR";    // GR Arion Eurovision
            host = "ice.onestreaming.com";
            path = "/arion";
            zanr="       NATIONAL";
            httpPort =80;
            break;

         case 61:
            nazev = "Athens Party GR";    // GR Athens Party
            host = "ice.onestreaming.com";
            path = "/athensparty";
            zanr="     POP , DANCE";
            httpPort =80;
            break;

         case 62:
            nazev = "Chroma Radio GR";    // GR Chroma Radio
            host = "chromaradio.com";
            path = "/";
            zanr="       HITY 80";
            httpPort =8002;
            break;

         case 63:
            nazev = "Fun Radio Top 20";    // SK Fun Radio Top 20
            host = "stream.funradio.sk";
            path = "/fun128.mp3";
            zanr="       TOP 40";
            httpPort =8000;
            break;

            case 64:
            nazev = "Radio Capris Dalmacija";    // SI Radio Capris Dalmacija
            host = "stream02.exit.si";
            path = "/DALMACIJA?";
            zanr="        FOLK";
            httpPort =8000;
            break;

         case 65:
            nazev = "Radio Capris Slovinsko";    // SI Radio Capris Slovinsko
            host = "stream01.exit.si";
            path = "/live?";
            zanr="       NATIONAL";
            httpPort =8000;
            break;

         case 66:
            nazev = "Radio Capris 80s Slovinsko";    // SI Radio Capris 80s Slovinsko
            host = "stream02.exit.si";
            path = "/80?";
            zanr="       HITY 80";
            httpPort =8000;
            break;

         case 67:
            nazev = "Radio Capris 90s Slovinsko";    // SI Radio Capris 90s Slovinsko
            host = "stream02.exit.si";
            path = "/90?";
            zanr="       HITY 90";
            httpPort =8000;
            break;

         case 68:
            nazev = "Naxi - 80s Serbia";    // RS Radio Naxi - 80s Serbia
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       HITY 80";
            httpPort =8040;
            break;

         case 69:
            nazev = "Naxi - Caffe Serbia";    // RS Radio Naxi - Caffe Serbia
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       OLDIES";
            httpPort =8020;
            break;

         case 70:
            nazev = "Naxi - Clubbing Serbia";    // RS Radio Naxi - Clubbing Serbia
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       DANCE";
            httpPort =8090;
            break;

         case 71:
            nazev = "Naxi - Serbian Evergreen";    // RS Radio Naxi - Serbian Evergreen
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       NATIONAL";
            httpPort =8010;
            break;

         case 72:
            nazev = "RSG - Relax Serbian ";    // RS Radio RSG - Relax
            host = "stream.rsg.rs";
            path = "/stream";
            zanr="       RELAX";
            httpPort =8063;
            break;

         case 73:
            nazev = "Akous Dreams Greece";    // GR Akous Dreams
            host = "ice.onestreaming.com";
            path = "/akousdreams";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 74:
            nazev = "COTN Radio UK";    // UK COTN Radio
            host = "streaming.smartradio.ch";
            path = "/stream";
            zanr="       RELAX";
            httpPort =8010;
            break;

         case 75:
            nazev = "Europa Plus - Light Russia";    // RU Europa Plus - Light
            host = "emg02.hostingradio.ru";
            path = "/ep-light128.mp3";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 76:
            nazev = "FFH Lounge DE";    // DE FFH Lounge
            host = "mp3.ffh.de";
            path = "/ffhchannels/hqlounge.mp3";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 77:
            nazev = "Frequence Verte";    // FR Fréquence Verte
            host = "listen.radioking.com";
            path = "/radio/209212/stream/252127";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 78:
            nazev = "Gamma Gioiosa Lovesongs";    // IT Gamma Gioiosa Lovesongs
            host = "95.110.186.253";
            path = "/gammalove.mp3";
            zanr="        LOVE";
            httpPort =8000;
            break;

         case 79:
            nazev = "Hitradio RT 1 DE";    // DE Hitradio RT 1 - Relax
            host = "rt1-ais-edge-3001.fra-eco.cdn.addradio.net";
            path = "/rt1/relax/mp3/high/stream.mp3";
            zanr="        LOVE";
            httpPort =80;
            break;

         case 80:
            nazev = "MFM MLady France";    // FR MFM MLady
            host = "mfm.ice.infomaniak.ch";
            path = "/mfm-128.mp3";
            zanr="        LOVE";
            httpPort =80;
            break;

         case 81:
            nazev = "Fun Radio Czechoslovakia";    // SK Fun Radio Czechoslovakia 
            host = "stream.funradio.sk";
            path = "/cs128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 82:
            nazev = "Fun Radio Running SK";    // SK Fun Radio Running 
            host = "stream.funradio.sk";
            path = "/fun128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 83:
            nazev = "Radio Beta SK";    // SK Radio Beta
            host = "109.71.67.102";
            path = "/beta_live_high.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 84:
            nazev = "Radio Frontinus SK";    // SK Rádio Frontinus
            host = "stream.frontinus.sk";
            path = "/frontinus128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 85:
            nazev = "Radio SiTy SK";    // SK Rádio SiTy
            host = "icecast.radiosity.sk";
            path = "/hq.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 86:
            nazev = "Radio Plus Nitra 105.9 SK";    // SK Rádio Plus Nitra
            host = "stream.sepia.sk";
            path = "/plus128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 87:
            nazev = "Radio Viva SK";    // SK Rádio Viva
            host = "stream.sepia.sk";
            path = "/viva128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 88:
            nazev = "RTVS Radio Devin SK";    // SK Rádio Devín
            host = "icecast.stv.livebox.sk";
            path = "/devin_128.mp3";
            zanr="       OLDIES";
            httpPort =80;
            break;

         case 89:
            nazev = "SKY Radio SK";    // SK SKY Rádio
            host = "stream.skyradio.sk";
            path = "/sky128";
            zanr="       RUZNE";
            httpPort =8000;
            break;

         case 90:
            nazev = "Radio Hana CZ";    // CZ Radio Hana
            host = "icecast8.play.cz";
            path = "/hana160.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 91:
            nazev = "AB Click and Country CZ";    // CZ AB Click and Country
            host = "62.168.118.229";
            path = "/clickandcountry.mp3";
            zanr="      COUNTRY";
            httpPort =8000;
            break;

         case 92:
            nazev = "AB Oldies Rock CZ";    // CZ AB Oldies Rock
            host = "mp3stream4.abradio.cz";
            path = "/oldiesrock128.mp3";
            zanr="       OLDIES";
            httpPort =80;
            break;

         case 93:
            nazev = "AB Rock Radio Prachen CZ";    // CZ AB Rock Radio Prácheň
            host = "ice.abradio.cz";
            path = "/prachen128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 94:
            nazev = "Cesky Impuls 981 AM";    // CZ Český Impuls 981 AM
            host = "icecast6.play.cz";
            path = "/cesky-impuls.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 95:
            nazev = "Cesky Rozhlas Brno";    // CZ ČRo Brno
            host = "icecast2.play.cz";
            path = "/crobrno128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 96:
            nazev = "Cesky Rozhlas Budejovice";    // CZ ČRo Budějovice
            host = "icecast2.play.cz";
            path = "/crocb128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 97:
            nazev = "Cesky Rozhlas Hradec Kralove";    // CZ ČRo Hradec Králové
            host = "icecast2.play.cz";
            path = "/crohk128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 98:
            nazev = "Cesky Rozhlas Karlovy Vary";    // CZ ČRo Karlovy Vary
            host = "icecast2.play.cz";
            path = "/crokv128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 99:
            nazev = "Cesky Rozhlas Liberec";    // CZ ČRo Liberec
            host = "icecast2.play.cz";
            path = "/croliberec128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 100:
            nazev = "Cesky Rozhlas Olomouc";    // CZ ČRo Olomouc
            host = "icecast2.play.cz";
            path = "/crool128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 101:
            nazev = "Cesky Rozhlas Ostrava";    // CZ ČRo Ostrava
            host = "icecast2.play.cz";
            path = "/croov128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 102:
            nazev = "Cesky Rozhlas Pardubice";    // CZ ČRo Pardubice
            host = "icecast2.play.cz";
            path = "/cropardubice128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 103:
            nazev = "Cesky Rozhlas Plzen";    // CZ ČRo Plzeň
            host = "icecast2.play.cz";
            path = "/croplzen128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 104:
            nazev = "Cesky Rozhlas Plus";    // CZ ČRo Plus
            host = "icecast1.play.cz";
            path = "/croplus128.mp3";
            zanr="    MLUVENE SLOVO";
            httpPort =80;
            break;

         case 105:
            nazev = "Cesky Rozhlas Regina";    // CZ ČRo Regina
            host = "icecast2.play.cz";
            path = "/croregina128.mp3";
            zanr="     REGIONALNI";
            httpPort =80;
            break;

         case 106:
            nazev = "Cesky Rozhlas Sever";    // CZ ČRo Sever
            host = "icecast2.play.cz";
            path = "/crosever128.mp3";
            zanr="     REGIONALNI";
            httpPort =80;
            break;

         case 107:
            nazev = "Cesky Rozhlas Stredocesky";    // CZ ČRo Stredocesky
            host = "icecast2.play.cz";
            path = "/croregion128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break; 

         case 108:
            nazev = "Cesky Rozhlas Vysocina";    // CZ ČRo Vysočina
            host = "icecast2.play.cz";
            path = "/crovysocina128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 109:
            nazev = "Evropa 2 Flashback CZ";    // CZ Evropa 2 Flashback
            host = "ice.actve.net";
            path = "/web-e2-flashback";
            zanr="        POP";
            httpPort =80;
            break;

         case 110:
            nazev = "Evropa 2 Hot CZ";    // CZ Evropa 2 Hot
            host = "ice.actve.net";
            path = "/web-e2-hot";
            zanr="        POP";
            httpPort =80;
            break;

         case 111:
            nazev = "Evropa 2 Movin CZ";    // CZ Evropa 2 Movin
            host = "ice.actve.net";
            path = "/web-e2-movin";
            zanr="        POP";
            httpPort =80;
            break;

         case 112:
            nazev = "Evropa 2 Top 40 CZ";    // CZ Evropa 2 Top 40
            host = "ice.actve.net";
            path = "/web-e2-top40";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 113:
            nazev = "Expres Radio 90.3 FM CZ";    // CZ Expres Radio 90.3 FM
            host = "icecast5.play.cz";
            path = "/expres128mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 114:
            nazev = "Fajn Fresh CZ";    // CZ Fajn Fresh
            host = "ice.abradio.cz";
            path = "/fajnfresh128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 115:
            nazev = "Fajn Hard CZ";    // CZ Fajn Hard
            host = "ice.abradio.cz";
            path = "/fajn128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 116:
            nazev = "Free Radio 107 FM CZ";    // CZ Free Rádio 107 FM
            host = "icecast8.play.cz";
            path = "/freeradio128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 117:
            nazev = "Frekvence 1 CZ";    // CZ Frekvence 1
            host = "icecast4.play.cz";
            path = "/frekvence1-128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 118:
            nazev = "Frekvence 1 Czech Hitz";    // CZ Frekvence 1 Czech Hitz
            host = "ice.actve.net";
            path = "/fm-frekvence1-128";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 119:
            nazev = "Frekvence 1 Diskoteka CZ";    // CZ Frekvence 1 Diskoteka
            host = "icecast4.play.cz";
            path = "/frekvence1-128.mp3";
            zanr="       DISCO";
            httpPort =80;
            break;

         case 120:
            nazev = "Frekvence 1 Romantika CZ";    // CZ Frekvence 1 Romantika
            host = "ice.actve.net";
            path = "/fm-frekvence1-128";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 121:
            nazev = "Hitradio City 93,7 FM CZ";    // CZ Hitrádio City 93,7 FM
            host = "ice.abradio.cz";
            path = "/cityfm128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 122:
            nazev = "Hitradio City Devadesatka";    // CZ Hitrádio City Devadesátka
            host = "ice.abradio.cz";
            path = "/city90128.mp3";
            zanr="  DISKOTEKA 90 LET";
            httpPort =8000;
            break;

         case 123:
            nazev = "Hitradio City Osmdesatka";    // CZ Hitrádio City Osmdesátka
            host = "ice.abradio.cz";
            path = "/city80128.mp3";
            zanr="  DISKOTEKA 80 LET";
            httpPort =8000;
            break;

            case 124:
            nazev = "Hitradio City Zona Lazky";    // CZ Hitrádio City Zóna Lázky
            host = "ice.abradio.cz";
            path = "/cityzl128.mp3";
            zanr="       RUZNE";
            httpPort =8000;
            break;

            case 125:
            nazev = "Hitradio Crystal CZ";    // CZ Hitrádio Crystal
            host = "ice.abradio.cz";
            path = "/crystal128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 126:
            nazev = "Hitradio Dragon CZ";    // CZ Hitrádio Dragon
            host = "ice.abradio.cz";
            path = "/dragon128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 127:
            nazev = "Hitradio Faktor CZ";    // CZ Hitrádio Dragon
            host = "ice.abradio.cz";
            path = "/faktor128.mp3";
            zanr="       RUZNE";
            httpPort =8000;
            break;

         case 128:
            nazev = "Hitradio FM Plus CZ";    // CZ Hitrádio FM Plus
            host = "ice.abradio.cz";
            path = "/fmplus128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 129:
            nazev = "Hitradio Orion CZ";    // CZ Hitrádio Orion
            host = "ice.abradio.cz";
            path = "/orion128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 130:
            nazev = "Hitradio Orion Morava CZ";    // CZ Hitrádio Orion Morava
            host = "ice.abradio.cz";
            path = "/orionmorava128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 131:
            nazev = "Kiss 98 FM CZ";    // CZ Kiss 98FM
            host = "icecast4.play.cz";
            path = "/kiss128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 132:
            nazev = "Kiss Delta CZ";    // CZ Kiss Delta
            host = "icecast1.play.cz";
            path = "/kissdelta192.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 133:
            nazev = "Kiss Publikum CZ";    // CZ Kiss Publikum
            host = "icecast5.play.cz";
            path = "/expres128mp3";
            zanr="       RUZNE";
            httpPort =8000;
            break;

         case 134:
            nazev = "Radio Cas Brnensko CZ";    // CZ Radio Čas Brněnsko
            host = "icecast7.play.cz";
            path = "/casbrno128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 135:
            nazev = "Radio Cas Olomoucko CZ";    // CZ Radio Čas Olomoucko
            host = "icecast7.play.cz";
            path = "/casradioolomouc64.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 136:
            nazev = "Radio Cas Rock CZ";    // CZ Radio Čas Rock
            host = "icecast7.play.cz";
            path = "/casrock128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 137:
            nazev = "Radio Helax CZ";    // CZ Radio Helax
            host = "ice.abradio.cz";
            path = "/helax128.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 138:
            nazev = "Radio Impuls CZ";    // CZ Radio Impuls
            host = "icecast5.play.cz";
            path = "/impuls128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 139:
            nazev = "Radio Rubi"; 
            host = "icecast8.play.cz";       // Radio Rubi
            path = "/radiorubi128.mp3";
            zanr="       TOP 40";
            httpPort = 80;
            break;  

         case 140:
            nazev = "Radio Samson CZ"; 
            host = "icecast2.play.cz";       // CZ Radio Samson
            path = "/samsonfm128aac";
            zanr="       TOP 40";
            httpPort = 8000;
            break; 

         case 141:
            nazev = "Radio Spin CZ"; 
            host = "icecast1.play.cz";       // CZ Radio Spin
            path = "/spin128aac";
            zanr="      HIP HOP";
            httpPort = 8000;
            break;

         case 142:
            nazev = "Radio Zlin CZ"; 
            host = "212.111.2.151";       // CZ Radio Zlin
            path = "/radiozlin_128.mp3";
            zanr="       TOP 40";
            httpPort = 8000;
            break;

         case 143:
            nazev = "Route 66 CZ"; 
            host = "ice3.abradio.cz";       // CZ Route 66
            path = "/route128.mp3";
            zanr="       COUNTRY";
            httpPort = 80;
            break;

         case 144:
            nazev = "SeeJay CZ"; 
            host = "mp3stream.abradio.cz";       // CZ SeeJay
            path = "/seejay128.mp3";
            zanr="        DANCE";
            httpPort = 8000;
            break;

         case 145:
            nazev = "Cas Radio Ostravsko"; 
            host = "icecast1.play.cz";       // CZ Čas rádio Ostravsko
            path = "/casradio32aac";
            zanr="       RUZNE";
            httpPort = 8000;
            break;

         case 146:
            nazev = "Cas Radio Zlinsko"; 
            host = "icecast1.play.cz";       // CZ Čas rádio Zlínsko
            path = "/casradiozlin32aac";
            zanr="       RUZNE";
            httpPort = 80;
            break;

         case 147:
            nazev = "Signal Radio CZ"; 
            host = "icecast1.play.cz";       // CZ Signál rádio 
            path = "/signal192.mp3";
            zanr="       RUZNE";
            httpPort = 80;
            break;

         case 148:
            nazev = "Signal Radio CZ"; 
            host = "radio.ipip.cz";       // CZ Signál rádio 
            path = "/";
            zanr="       RUZNE";
            httpPort = 7996;
            break;


         case 149:
            nazev = "Color CZ"; 
            host = "sc.ipip.cz";       // CZ Color rádio 
            path = "/";
            zanr="       RUZNE";
            httpPort = 8206;
            break;

         case 150:
            nazev = "Radio Zlin 256 kB/s CZ"; 
            host = "212.111.2.151";       // CZ Rádio Zlín 256 kB / sec. 
            path = "/radiozlin_256.mp3";
            zanr="       RUZNE";
            httpPort = 8000;
            break;

            

            

    }

  
                                                      

    if(!webclient.connected() || pamet_ID_stanice!=ID_stanice){    
    
      if(webclient.connect(host, httpPort)){                                 // Adresa serveru se streamem - ve smyčce
       webclient.print(String("GET ") + path + " HTTP/1.1\r\n" +
                  "Host: " + host + "\r\n" + 
                  "Connection: close\r\n\r\n");
              pamet_ID_stanice=ID_stanice;
              Serial.println("");                                        // Prázdný řádek ve výpisu COM
              Serial.println(nazev);
              lcd.clear(); 
              lcd.setCursor(1,0);
              lcd.print("Predvolba: ");
              lcd.setCursor(12,0);  
              lcd.print(ID_stanice);
              
       //       lcd.setCursor(0,2);
       //       lcd.print("--------------------");       // Pro 4 - řádkový displej
       //       lcd.setCursor(0,3);
       //       lcd.print(zanr);
         
 
      }
     }
  
    if(webclient.available() > 0){                                          // Pokud je server dostupný, tak :
      uint8_t bytesread = webclient.read(mp3buff,32);                       // ulož přijatá data do bufferu
    MP3player.playChunk(mp3buff,bytesread);                              // a přehraj na VS1053B Shield
}  
   if (Prodleva >= 300){
       
  Posuv();
  MP3player.setVolume(Volume);  // Nižší číslo vyšší hlasitost
}
}



//----------------------------------
String Scroll_LCD_Left(String StrDisplay){
  String result;
  String StrProcess = "               " + StrDisplay + "               ";  // Mezera = znak na řádku displeje ( 16 )
  result = StrProcess.substring(Li,Lii);
  Li++;
  Lii++;
  if (Li>StrProcess.length()){
    Li=16;
    Lii=0;
  }
  return result;
}  

void Posuv(){
  Prodleva=0;
Delka_textu = nazev.length();

// for (int i = 0; i <= Delka_textu; i++) {                                                                            
    lcd.setCursor(0, 1);                                                
    lcd.print(Scroll_LCD_Left(nazev));   

} 
